summaryrefslogtreecommitdiffstats
path: root/build
diff options
context:
space:
mode:
authorEmma Foley <emma.l.foley@intel.com>2017-09-07 18:00:38 +0000
committerTim Rozet <trozet@redhat.com>2017-09-14 17:28:11 +0000
commit2784827b0d2e3e2f904964c89db2421d4ababebd (patch)
tree85cd5f6cbf05b38bb7a47d73d5482bbca201c8a8 /build
parent2e6b2fa375c2356f8af894c88f23d9738d8cf9c0 (diff)
baro: updating refs to collectd-ceilometer
Since Ceilometer support was removed from the collectd-ceilometer-plugin[1], the repo name and ceiloemter are misleading. A change was submitted to openstack-infra to rename the repo [2] This change removes references to collectd-ceilometer from apex. These changes are independant of the repo rename. [1] https://review.openstack.org/#/c/490823/ [2] https://review.openstack.org/#/c/500768/ Depends-On: I6cf22c081aa1e40f64995be40b6225855faf4092 Change-Id: Ib3a7766e28fd03a86a995eea4b9abc996498200e Signed-off-by: Emma Foley <emma.l.foley@intel.com>
Diffstat (limited to 'build')
-rwxr-xr-xbuild/barometer-install.sh26
1 files changed, 13 insertions, 13 deletions
diff --git a/build/barometer-install.sh b/build/barometer-install.sh
index de47baff..9e5dfc73 100755
--- a/build/barometer-install.sh
+++ b/build/barometer-install.sh
@@ -15,11 +15,11 @@
# limitations under the License.
# Get and install packages needed for Barometer service.
# These are: collectd rpm's and dependencies, collectd-ceilometer-plugin,
# puppet-barometer module.
# Versions/branches
-COLLECTD_CEILOMETER_PLUGIN_BRANCH="stable/ocata"
+COLLECTD_OPENSTACK_PLUGINS_BRANCH="stable/ocata"
ARCH="6.el7.centos.x86_64.rpm"
# don't fail because of missing certificate
@@ -27,7 +27,7 @@ GETFLAG="--no-check-certificate"
# Locations of repos
ARTIFACTS_BAROM="artifacts.opnfv.org/barometer"
-COLLECTD_CEILOMETER_REPO="https://github.com/openstack/collectd-ceilometer-plugin"
+COLLECTD_OPENSTACK_REPO="https://github.com/openstack/collectd-ceilometer-plugin"
PUPPET_BAROMETER_REPO="https://github.com/johnhinman/puppet-barometer"
# upload barometer packages tar, extract, and install
@@ -76,12 +76,12 @@ function barometer_pkgs {
cp collectd.tar.gz ${BUILD_DIR}
popd > /dev/null
- # get collectd-ceilometer-plugin and tar it
- rm -rf collectd-ceilometer-plugin
- git clone https://github.com/openstack/collectd-ceilometer-plugin
- pushd collectd-ceilometer-plugin
- git checkout -b $COLLECTD_CEILOMETER_PLUGIN_BRANCH
- git archive --format=tar.gz HEAD > ${BUILD_DIR}/collectd-ceilometer-plugin.tar.gz
+ # get collectd-openstack-plugins and tar it
+ rm -rf collectd-openstack-plugins
+ git clone $COLLECTD_OPENSTACK_REPO collectd-openstack-plugins
+ pushd collectd-openstack-plugins
+ git checkout -b $COLLECTD_OPENSTACK_PLUGINS_BRANCH
+ git archive --format=tar.gz HEAD > ${BUILD_DIR}/collectd-openstack-plugins.tar.gz
popd > /dev/null
# get the barometer puppet module and tar it
@@ -103,7 +103,7 @@ function barometer_pkgs {
# install dependencies
LIBGUESTFS_BACKEND=direct virt-customize \
--upload ${BUILD_DIR}/collectd.tar.gz:/opt/ \
- --upload ${BUILD_DIR}/collectd-ceilometer-plugin.tar.gz:/opt/ \
+ --upload ${BUILD_DIR}/collectd-openstack-plugins.tar.gz:/opt/ \
--upload ${BUILD_DIR}/puppet-barometer.tar.gz:/etc/puppet/modules/ \
--run-command 'tar xfz /opt/collectd.tar.gz -C /opt' \
--install libstatgrab,log4cplus,rrdtool,rrdtool-devel \
@@ -133,12 +133,12 @@ function barometer_pkgs {
/opt/collectd-virt-${SUFFIX}" \
-a $OVERCLOUD_IMAGE
- # install collectd-ceilometer plugin
+ # install collectd-openstack-plugins
# install puppet-barometer module
# make directories for config files and mibs
LIBGUESTFS_BACKEND=direct virt-customize \
- --run-command 'mkdir /opt/stack/collectd-ceilometer' \
- --run-command "tar xfz /opt/collectd-ceilometer-plugin.tar.gz -C /opt/stack/collectd-ceilometer" \
+ --run-command 'mkdir /opt/stack/collectd-openstack' \
+ --run-command "tar xfz /opt/collectd-openstack-plugins.tar.gz -C /opt/stack/collectd-openstack" \
--run-command "cd /etc/puppet/modules/ && mkdir barometer && \
tar xzf puppet-barometer.tar.gz -C barometer" \
--run-command 'mkdir /usr/share/mibs/' \
@@ -15,11 +15,11 @@
# limitations under the License.
# Get and install packages needed for Barometer service.
-# These are: collectd rpm's and dependencies, collectd-ceilometer-plugin,
+# These are: collectd rpm's and dependencies, collectd-openstack-plugins,
# puppet-barometer module.
# Versions/branches